/* 
   Copyright (c) 1995 by Cisco systems, Inc.
   All rights reserved.

   Please NOTE:  None of the TACACS code available here comes with any
   warranty or support.
*/

#include "tac_plus.h"
#include "expire.h"

/* Choose an authentication function. Return 0 if chosen, 1 if we need
   a username, -1 on failure
*/

int
choose_authen(data, type)
struct authen_data *data;
struct authen_type *type;
{
    switch (data->action) {
    case TAC_PLUS_AUTHEN_SENDPASS:
	switch (type->authen_type) {
	case TAC_PLUS_AUTHEN_TYPE_CHAP:
	case TAC_PLUS_AUTHEN_TYPE_PAP:
	case TAC_PLUS_AUTHEN_TYPE_ARAP:
	    /* Do we have a username? */
	    if (!(char) data->NAS_id->username[0]) {
		/* get user name */
		return (CHOOSE_GETUSER);
	    }
	    type->authen_func = sndpass_fn;
	    strcpy(type->authen_name, "sndpass_fn");
	    return (CHOOSE_OK);

	case TAC_PLUS_AUTHEN_TYPE_ASCII:
	default:
	    break;
	}
	return (CHOOSE_FAILED);

    case TAC_PLUS_AUTHEN_LOGIN:
	/* Unless we're enabling, we need a username */
	if (data->service != TAC_PLUS_AUTHEN_SVC_ENABLE) {
	    /* Do we have a username? */
	    if (!(char) data->NAS_id->username[0]) {
		/* get user name */
		return (CHOOSE_GETUSER);
	    }
	}
	/* Note: if service = ppp then make sure your authentication
	   function only sends getuser and/or getpass. Any prompt will
	   be ignored */
	type->authen_func = authenticate_fn;
	strcpy(type->authen_name, "authentication_fn");
	return (CHOOSE_OK);
	
    case TAC_PLUS_AUTHEN_CHPASS:
	return(CHOOSE_FAILED);

    default:
	break;
    }
    return (CHOOSE_FAILED);
}
